tidylog_mask: Mask with tidylog

Description Usage Arguments Value

View source: R/mask.R

Description

Make use of tidylog without masking in the global environment.

Usage

1

Arguments

x

A function or expression.

Value

If x evaluates to a function, then a new function is returned which is masked by the tidylog namespace. Otherwise, x is evaluated in a child environment of the tidylog namespace.


TylerGrantSmith/mask documentation built on Jan. 10, 2020, 12:05 a.m.