Description Usage Arguments Value Examples
Evaluate a function or expression in a masking environment
1 | mask(x, envir = rlang::caller_env())
|
x |
A function or an expression |
envir |
An environment or a name of a package as a 'character', which should be injected between the execution environment and the current parent environment. |
In the case that 'x' is a function, the result is a a copy of the function in a new enclosing environment. Otherwise, the result of 'x' executing in the new environment.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.