Description Usage Arguments Value
Make use of tidylog without masking in the global environment.
1 | tidylog_mask(x)
|
x |
A function or expression. |
If x evaluates to a function, then a new function is returned which is masked by the tidylog namespace. Otherwise, x is evaluated in a child environment of the tidylog namespace.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.